/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QBS_ITEMDECLARATION_H
#define QBS_ITEMDECLARATION_H

#include "deprecationinfo.h"
#include "itemtype.h"
#include "propertydeclaration.h"
#include <tools/set.h>

#include <QtCore/qstring.h>

namespace qbs {
namespace Internal {

class ItemDeclaration
{
public:
    ItemDeclaration(ItemType type = ItemType::Unknown);

    ItemType type() const { return m_type; }

    using Properties = QList<PropertyDeclaration>;
    void setProperties(const Properties &props) { m_properties = props; }
    Properties properties() const { return m_properties; }

    void setDeprecationInfo(const DeprecationInfo &di) { m_deprecationInfo = di; }
    DeprecationInfo deprecationInfo() const { return m_deprecationInfo; }

    ItemDeclaration &operator<<(const PropertyDeclaration &decl);

    using TypeNames = Set<ItemType>;
    void setAllowedChildTypes(const TypeNames &typeNames) { m_allowedChildTypes = typeNames; }
    const TypeNames &allowedChildTypes() const { return m_allowedChildTypes; }
    bool isChildTypeAllowed(ItemType type) const;

    ErrorInfo checkForDeprecation(DeprecationWarningMode mode, const QString &name,
                                  const CodeLocation &loc, Logger &logger) const;

private:
    ItemType m_type;
    Properties m_properties;
    TypeNames m_allowedChildTypes;
    DeprecationInfo m_deprecationInfo;
};

} // namespace Internal
} // namespace qbs

#endif // QBS_ITEMDECLARATION_H
