// This file is autogenerated. Changes will be overwritten.
#include "TBWJOC4PT5/moc_ivisualstudiosolutionproject.cpp"
#include "TBWJOC4PT5/moc_visualstudiosolution.cpp"
#include "TBWJOC4PT5/moc_visualstudiosolutionfileproject.cpp"
#include "TBWJOC4PT5/moc_visualstudiosolutionfolderproject.cpp"
#include "TBWJOC4PT5/moc_visualstudiosolutionglobalsection.cpp"
