/****************************************************************************
** Meta object code from reading C++ file 'jobs.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qbs/src/lib/corelib/api/jobs.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jobs.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3qbs11AbstractJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::AbstractJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs11AbstractJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::AbstractJob",
        "taskStarted",
        "",
        "description",
        "maximumProgressValue",
        "qbs::AbstractJob*",
        "job",
        "totalEffortChanged",
        "totalEffort",
        "taskProgress",
        "newProgressValue",
        "finished",
        "success",
        "cancel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'taskStarted'
        QtMocHelpers::SignalData<void(const QString &, int, qbs::AbstractJob *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'totalEffortChanged'
        QtMocHelpers::SignalData<void(int, qbs::AbstractJob *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'taskProgress'
        QtMocHelpers::SignalData<void(int, qbs::AbstractJob *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(bool, qbs::AbstractJob *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractJob, qt_meta_tag_ZN3qbs11AbstractJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::AbstractJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs11AbstractJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs11AbstractJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs11AbstractJobE_t>.metaTypes,
    nullptr
} };

void qbs::AbstractJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->taskStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qbs::AbstractJob*>>(_a[3]))); break;
        case 1: _t->totalEffortChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qbs::AbstractJob*>>(_a[2]))); break;
        case 2: _t->taskProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qbs::AbstractJob*>>(_a[2]))); break;
        case 3: _t->finished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qbs::AbstractJob*>>(_a[2]))); break;
        case 4: _t->cancel(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< qbs::AbstractJob* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< qbs::AbstractJob* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< qbs::AbstractJob* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< qbs::AbstractJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractJob::*)(const QString & , int , qbs::AbstractJob * )>(_a, &AbstractJob::taskStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJob::*)(int , qbs::AbstractJob * )>(_a, &AbstractJob::totalEffortChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJob::*)(int , qbs::AbstractJob * )>(_a, &AbstractJob::taskProgress, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJob::*)(bool , qbs::AbstractJob * )>(_a, &AbstractJob::finished, 3))
            return;
    }
}

const QMetaObject *qbs::AbstractJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::AbstractJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs11AbstractJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qbs::AbstractJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void qbs::AbstractJob::taskStarted(const QString & _t1, int _t2, qbs::AbstractJob * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void qbs::AbstractJob::totalEffortChanged(int _t1, qbs::AbstractJob * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void qbs::AbstractJob::taskProgress(int _t1, qbs::AbstractJob * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void qbs::AbstractJob::finished(bool _t1, qbs::AbstractJob * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN3qbs15SetupProjectJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::SetupProjectJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs15SetupProjectJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::SetupProjectJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SetupProjectJob, qt_meta_tag_ZN3qbs15SetupProjectJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::SetupProjectJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs15SetupProjectJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs15SetupProjectJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs15SetupProjectJobE_t>.metaTypes,
    nullptr
} };

void qbs::SetupProjectJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SetupProjectJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qbs::SetupProjectJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::SetupProjectJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs15SetupProjectJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractJob::qt_metacast(_clname);
}

int qbs::SetupProjectJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3qbs8BuildJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::BuildJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs8BuildJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::BuildJob",
        "reportCommandDescription",
        "",
        "highlight",
        "message",
        "reportProcessResult",
        "qbs::ProcessResult",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reportCommandDescription'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'reportProcessResult'
        QtMocHelpers::SignalData<void(const qbs::ProcessResult &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BuildJob, qt_meta_tag_ZN3qbs8BuildJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::BuildJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8BuildJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8BuildJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs8BuildJobE_t>.metaTypes,
    nullptr
} };

void qbs::BuildJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BuildJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reportCommandDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->reportProcessResult((*reinterpret_cast<std::add_pointer_t<qbs::ProcessResult>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BuildJob::*)(const QString & , const QString & )>(_a, &BuildJob::reportCommandDescription, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BuildJob::*)(const qbs::ProcessResult & )>(_a, &BuildJob::reportProcessResult, 1))
            return;
    }
}

const QMetaObject *qbs::BuildJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::BuildJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8BuildJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractJob::qt_metacast(_clname);
}

int qbs::BuildJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void qbs::BuildJob::reportCommandDescription(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void qbs::BuildJob::reportProcessResult(const qbs::ProcessResult & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3qbs8CleanJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::CleanJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs8CleanJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::CleanJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CleanJob, qt_meta_tag_ZN3qbs8CleanJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::CleanJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8CleanJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8CleanJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs8CleanJobE_t>.metaTypes,
    nullptr
} };

void qbs::CleanJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CleanJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qbs::CleanJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::CleanJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8CleanJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractJob::qt_metacast(_clname);
}

int qbs::CleanJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3qbs10InstallJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::InstallJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs10InstallJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::InstallJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InstallJob, qt_meta_tag_ZN3qbs10InstallJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::InstallJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs10InstallJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs10InstallJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs10InstallJobE_t>.metaTypes,
    nullptr
} };

void qbs::InstallJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InstallJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qbs::InstallJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::InstallJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs10InstallJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractJob::qt_metacast(_clname);
}

int qbs::InstallJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractJob::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
