/****************************************************************************
** Meta object code from reading C++ file 'internaljobs.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qbs/src/lib/corelib/api/internaljobs.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'internaljobs.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3qbs8Internal11InternalJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::Internal::InternalJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs8Internal11InternalJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::Internal::InternalJob",
        "finished",
        "",
        "Internal::InternalJob*",
        "job",
        "newTaskStarted",
        "description",
        "totalEffort",
        "totalEffortChanged",
        "taskProgress",
        "value",
        "reportCommandDescription",
        "highlight",
        "message"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(Internal::InternalJob *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'newTaskStarted'
        QtMocHelpers::SignalData<void(const QString &, int, Internal::InternalJob *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 7 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'totalEffortChanged'
        QtMocHelpers::SignalData<void(int, Internal::InternalJob *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'taskProgress'
        QtMocHelpers::SignalData<void(int, Internal::InternalJob *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'reportCommandDescription'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InternalJob, qt_meta_tag_ZN3qbs8Internal11InternalJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::Internal::InternalJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal11InternalJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal11InternalJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs8Internal11InternalJobE_t>.metaTypes,
    nullptr
} };

void qbs::Internal::InternalJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InternalJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<Internal::InternalJob*>>(_a[1]))); break;
        case 1: _t->newTaskStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Internal::InternalJob*>>(_a[3]))); break;
        case 2: _t->totalEffortChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Internal::InternalJob*>>(_a[2]))); break;
        case 3: _t->taskProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Internal::InternalJob*>>(_a[2]))); break;
        case 4: _t->reportCommandDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InternalJob::*)(Internal::InternalJob * )>(_a, &InternalJob::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InternalJob::*)(const QString & , int , Internal::InternalJob * )>(_a, &InternalJob::newTaskStarted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InternalJob::*)(int , Internal::InternalJob * )>(_a, &InternalJob::totalEffortChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InternalJob::*)(int , Internal::InternalJob * )>(_a, &InternalJob::taskProgress, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InternalJob::*)(const QString & , const QString & )>(_a, &InternalJob::reportCommandDescription, 4))
            return;
    }
}

const QMetaObject *qbs::Internal::InternalJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::Internal::InternalJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal11InternalJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qbs::Internal::InternalJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void qbs::Internal::InternalJob::finished(Internal::InternalJob * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qbs::Internal::InternalJob::newTaskStarted(const QString & _t1, int _t2, Internal::InternalJob * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void qbs::Internal::InternalJob::totalEffortChanged(int _t1, Internal::InternalJob * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void qbs::Internal::InternalJob::taskProgress(int _t1, Internal::InternalJob * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void qbs::Internal::InternalJob::reportCommandDescription(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN3qbs8Internal24InternalJobThreadWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::Internal::InternalJobThreadWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs8Internal24InternalJobThreadWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::Internal::InternalJobThreadWrapper",
        "startRequested",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InternalJobThreadWrapper, qt_meta_tag_ZN3qbs8Internal24InternalJobThreadWrapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::Internal::InternalJobThreadWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<InternalJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal24InternalJobThreadWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal24InternalJobThreadWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs8Internal24InternalJobThreadWrapperE_t>.metaTypes,
    nullptr
} };

void qbs::Internal::InternalJobThreadWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InternalJobThreadWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startRequested(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InternalJobThreadWrapper::*)()>(_a, &InternalJobThreadWrapper::startRequested, 0))
            return;
    }
}

const QMetaObject *qbs::Internal::InternalJobThreadWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::Internal::InternalJobThreadWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal24InternalJobThreadWrapperE_t>.strings))
        return static_cast<void*>(this);
    return InternalJob::qt_metacast(_clname);
}

int qbs::Internal::InternalJobThreadWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = InternalJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void qbs::Internal::InternalJobThreadWrapper::startRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN3qbs8Internal23InternalSetupProjectJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::Internal::InternalSetupProjectJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs8Internal23InternalSetupProjectJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::Internal::InternalSetupProjectJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InternalSetupProjectJob, qt_meta_tag_ZN3qbs8Internal23InternalSetupProjectJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::Internal::InternalSetupProjectJob::staticMetaObject = { {
    QMetaObject::SuperData::link<InternalJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal23InternalSetupProjectJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal23InternalSetupProjectJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs8Internal23InternalSetupProjectJobE_t>.metaTypes,
    nullptr
} };

void qbs::Internal::InternalSetupProjectJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InternalSetupProjectJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qbs::Internal::InternalSetupProjectJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::Internal::InternalSetupProjectJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal23InternalSetupProjectJobE_t>.strings))
        return static_cast<void*>(this);
    return InternalJob::qt_metacast(_clname);
}

int qbs::Internal::InternalSetupProjectJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = InternalJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3qbs8Internal21BuildGraphTouchingJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::Internal::BuildGraphTouchingJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs8Internal21BuildGraphTouchingJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::Internal::BuildGraphTouchingJob",
        "reportProcessResult",
        "",
        "qbs::ProcessResult",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reportProcessResult'
        QtMocHelpers::SignalData<void(const qbs::ProcessResult &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BuildGraphTouchingJob, qt_meta_tag_ZN3qbs8Internal21BuildGraphTouchingJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::Internal::BuildGraphTouchingJob::staticMetaObject = { {
    QMetaObject::SuperData::link<InternalJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal21BuildGraphTouchingJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal21BuildGraphTouchingJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs8Internal21BuildGraphTouchingJobE_t>.metaTypes,
    nullptr
} };

void qbs::Internal::BuildGraphTouchingJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BuildGraphTouchingJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reportProcessResult((*reinterpret_cast<std::add_pointer_t<qbs::ProcessResult>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BuildGraphTouchingJob::*)(const qbs::ProcessResult & )>(_a, &BuildGraphTouchingJob::reportProcessResult, 0))
            return;
    }
}

const QMetaObject *qbs::Internal::BuildGraphTouchingJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::Internal::BuildGraphTouchingJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal21BuildGraphTouchingJobE_t>.strings))
        return static_cast<void*>(this);
    return InternalJob::qt_metacast(_clname);
}

int qbs::Internal::BuildGraphTouchingJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = InternalJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void qbs::Internal::BuildGraphTouchingJob::reportProcessResult(const qbs::ProcessResult & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3qbs8Internal16InternalBuildJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::Internal::InternalBuildJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs8Internal16InternalBuildJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::Internal::InternalBuildJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InternalBuildJob, qt_meta_tag_ZN3qbs8Internal16InternalBuildJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::Internal::InternalBuildJob::staticMetaObject = { {
    QMetaObject::SuperData::link<BuildGraphTouchingJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal16InternalBuildJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal16InternalBuildJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs8Internal16InternalBuildJobE_t>.metaTypes,
    nullptr
} };

void qbs::Internal::InternalBuildJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InternalBuildJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qbs::Internal::InternalBuildJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::Internal::InternalBuildJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal16InternalBuildJobE_t>.strings))
        return static_cast<void*>(this);
    return BuildGraphTouchingJob::qt_metacast(_clname);
}

int qbs::Internal::InternalBuildJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BuildGraphTouchingJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3qbs8Internal16InternalCleanJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::Internal::InternalCleanJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs8Internal16InternalCleanJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::Internal::InternalCleanJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InternalCleanJob, qt_meta_tag_ZN3qbs8Internal16InternalCleanJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::Internal::InternalCleanJob::staticMetaObject = { {
    QMetaObject::SuperData::link<BuildGraphTouchingJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal16InternalCleanJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal16InternalCleanJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs8Internal16InternalCleanJobE_t>.metaTypes,
    nullptr
} };

void qbs::Internal::InternalCleanJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InternalCleanJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qbs::Internal::InternalCleanJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::Internal::InternalCleanJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal16InternalCleanJobE_t>.strings))
        return static_cast<void*>(this);
    return BuildGraphTouchingJob::qt_metacast(_clname);
}

int qbs::Internal::InternalCleanJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BuildGraphTouchingJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3qbs8Internal18InternalInstallJobE_t {};
} // unnamed namespace

template <> constexpr inline auto qbs::Internal::InternalInstallJob::qt_create_metaobjectdata<qt_meta_tag_ZN3qbs8Internal18InternalInstallJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qbs::Internal::InternalInstallJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InternalInstallJob, qt_meta_tag_ZN3qbs8Internal18InternalInstallJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qbs::Internal::InternalInstallJob::staticMetaObject = { {
    QMetaObject::SuperData::link<InternalJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal18InternalInstallJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal18InternalInstallJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3qbs8Internal18InternalInstallJobE_t>.metaTypes,
    nullptr
} };

void qbs::Internal::InternalInstallJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InternalInstallJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qbs::Internal::InternalInstallJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qbs::Internal::InternalInstallJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3qbs8Internal18InternalInstallJobE_t>.strings))
        return static_cast<void*>(this);
    return InternalJob::qt_metacast(_clname);
}

int qbs::Internal::InternalInstallJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = InternalJob::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
